@@ -10,9 +10,16 @@ import re
 import textwrap
 
 
+QUOTE_PATTERN = re.compile(ur'[\"\u201c\u201e\u00ab]\s?(.+?)\s?[\"\u201c\u201d\u00bb]')
+LINK_PATTERN = re.compile(r'https?://')
+
+
 def dedent(string):
     return textwrap.dedent(string).replace('\n', '')
 
 def extract_quotes(string):
-    QUOTE_PATTERN = ur'[\"\u201c\u201e\u00ab]\s?(.+?)\s?[\"\u201c\u201d\u00bb]'
-    return re.findall(QUOTE_PATTERN, string)
\ No newline at end of file
+    return re.findall(QUOTE_PATTERN, string)
+
+def extract_links(string):
+    words = string.split(' ')
+    return [word for word in words if re.match(LINK_PATTERN, word)]
